@@ -1,13 +1,16 @@
-## List defined symbols
-## @export
-#ls_sym <- function() {
-#  ensure_sympy()
-#  
-#  glb_syms <- reticulate::py_eval("globals()")
-#  glb_syms <- glb_syms[-(seq_len(pkg_globals$internal_globals_length))]
-#  
-#  return(names(glb_syms))
-#}
+#' List defined symbols
+#' 
+#' @concept caracas_symbol
+#' 
+#' @export
+ls_sym <- function() {
+ ensure_sympy()
+ 
+ glb_syms <- reticulate::py_eval("globals()")
+ glb_syms <- glb_syms[-(seq_len(pkg_globals$internal_globals_length))]
+ 
+ return(names(glb_syms))
+}
 
 #' Ask for a symbol's property
 #' 
